import "@blocknote/core/fonts/inter.css";
import { BlockNoteView } from "@blocknote/mantine";
import "@blocknote/mantine/style.css";
import { useCreateBlockNote } from "@blocknote/react";
import { Block, BlockNoteEditor, PartialBlock } from "@blocknote/core";
import React from "react";
import { useEffect, useMemo, useState } from "react";
import ReactDOM from "react-dom/client"
import { createRoot } from "react-dom/client";
import r2wc from "react-to-webcomponent"




async function saveToStorage(id, jsonBlocks) {
  localStorage.setItem(`editorContent-${id}`, JSON.stringify(jsonBlocks));
}

async function loadFromStorage(id) {
  const storageString = localStorage.getItem(`editorContent-${id}`);
  return storageString ? JSON.parse(storageString) : undefined;
}

function Editor({ id }) {
  const [initialContent, setInitialContent] = useState("loading");

  useEffect(() => {
    loadFromStorage(id).then((content) => {
      setInitialContent(content);
    });
  }, [id]);

  const editor = useMemo(() => {
    if (initialContent === "loading") {
      return undefined;
    }
    return BlockNoteEditor.create({ initialContent });
  }, [initialContent]);

  if (editor === undefined) {
    return "Loading content...";
  }

  return (
    <BlockNoteView
      editor={editor}
      onChange={() => {
        saveToStorage(id, editor.document);
      }}
    />
  );
}

const WCEditor = r2wc(Editor, React, ReactDOM, {props: {"id": "string"}});

customElements.define("block-note-editor", WCEditor);




